Package

Struct Package 

pub struct Package { /* private fields */ }
A package in the form of a directory.

Implementations

Source

impl Package

pub fn to_initialised( &self, initialise_options: InitialiseOptions, ) -> Result<InitialisedPackage>

Initialises this package if needed, and returns an InitialisedPackage.

Source

impl Package

pub fn export_distributable( &self, options: ExportOptions, ) -> Result<Distributable>

Exports the package as a distributable .merlon file.

Source

impl Package

pub fn new<N>(name: N, path: PathBuf) -> Result<Self>
where N: TryIntoName,

Create a new package at the given path. The path must not exist.

pub fn edit_manifest<F>(&self, f: F) -> Result<()>
where F: FnOnce(&mut Manifest) -> Result<()>,

Edit the package manifest. The given function will be called with a mutable reference to the manifest, and after the function returns the manifest will be written back to disk.

Source

impl Package

pub fn current() -> Result<Option<Self>>

Gets the current package, if any, by looking for merlon.toml in the current directory and its parents.

pub fn id(&self) -> Result<Id>

The package ID.

pub fn path(&self) -> &Path

The package path.

pub fn readme(&self) -> Result<String>

Returns the text content of the README.md file in the package.

pub fn manifest(&self) -> Result<Manifest>

Returns the manifest of the package by parsing the merlon.toml file.

pub fn uuid_equals(&self, other: &Package) -> Result<bool>

Compares two packages by ID.

pub fn copyright_notice(&self) -> Result<String>

Returns a copyright notice for this package by reading the package’s LICENSE file.

Source

impl Package

pub fn clone_to_dir(&self, path: PathBuf) -> Result<Self>

Copies the package to the given path and updates. The path must not exist. Effectively a set_path method.