pub struct Package { /* private fields */ }Expand description
A package in the form of a directory.
Implementations
Sourceimpl Package
impl Package
Sourcepub fn to_initialised(
&self,
initialise_options: InitialiseOptions,
) -> Result<InitialisedPackage>
pub fn to_initialised( &self, initialise_options: InitialiseOptions, ) -> Result<InitialisedPackage>
Initialises this package if needed, and returns an InitialisedPackage.
Sourceimpl Package
impl Package
Sourcepub fn export_distributable(
&self,
options: ExportOptions,
) -> Result<Distributable>
pub fn export_distributable( &self, options: ExportOptions, ) -> Result<Distributable>
Exports the package as a distributable .merlon file.
Sourceimpl Package
impl Package
Sourcepub fn new<N>(name: N, path: PathBuf) -> Result<Self>where
N: TryIntoName,
pub fn new<N>(name: N, path: PathBuf) -> Result<Self>where
N: TryIntoName,
Create a new package at the given path. The path must not exist.
Sourceimpl Package
impl Package
Sourcepub fn current() -> Result<Option<Self>>
pub fn current() -> Result<Option<Self>>
Gets the current package, if any, by looking for merlon.toml in the current directory and its parents.
Sourcepub fn readme(&self) -> Result<String>
pub fn readme(&self) -> Result<String>
Returns the text content of the README.md file in the package.
Sourcepub fn manifest(&self) -> Result<Manifest>
pub fn manifest(&self) -> Result<Manifest>
Returns the manifest of the package by parsing the merlon.toml file.
Sourcepub fn uuid_equals(&self, other: &Package) -> Result<bool>
pub fn uuid_equals(&self, other: &Package) -> Result<bool>
Compares two packages by ID.
Sourcepub fn copyright_notice(&self) -> Result<String>
pub fn copyright_notice(&self) -> Result<String>
Returns a copyright notice for this package by reading the package’s LICENSE file.